<?php
/**
 * Migration scripts for MagazineX theme.
 *
 * @package    WPBlockArt
 * @subpackage MagazineX
 * @since      MagazineX TBD
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

function magazinex_customizer_migration_v1() {

	$demo_import_migration = magazinex_demo_import_migration();

	// Migrate the customize option if migration is done manually.
	if ( ! $demo_import_migration ) {

		// Bail out if the migration is already done.
		if ( get_option( 'magazinex_customizer_migration_v1' ) ) {
			return;
		}
	}

	// Global.
	$inside_container_background_color = get_theme_mod( 'magazinex_inside_container_bg_color', '#F5F9FF' );

	// Header.
	$logo_height = get_theme_mod( 'magazinex_site_logo_height', '' );

	$main_header_layout     = get_theme_mod( 'magazinex_primary_header_layout', 'layout-1' );
	$main_header_background = get_theme_mod( 'magazinex_primary_header_background', '#FFFFFF' );

	$enable_drawer                   = get_theme_mod( 'magazinex_enable_drawer_menu', 0 );
	$drawer_content_background_color = get_theme_mod( 'magazinex_drawer_background_color', '' );

	$enable_header_search = get_theme_mod( 'magazinex_enable_search', 1 );

	$enable_breadcrumb = get_theme_mod( 'magazinex_enable_breadcrumbs', true );

	// Content.
	$enable_pagination = get_theme_mod( 'magazinex_pagination_style', 'default' );
	$pagination_layout = get_theme_mod( 'magazinex_pagination_style', 'default' );

	// Footer.
	$footer_background_color        = get_theme_mod( 'magazinex_footer_bar_bg_color', '' );
	$footer_column_layout           = get_theme_mod( 'magazinex_footer_column_layout', 'mzx-grid-cols--3' );
	$footer_column_background_color = get_theme_mod( 'magazinex_footer_column_background_color', '' );
	$footer_column_headings_color   = get_theme_mod( 'magazinex_footer_column_heading_color', '' );

	if ( '' !== $footer_background_color ) {
		set_theme_mod( 'magazinex_footer_bar_background', $footer_background_color );
	}

	if ( '' !== $footer_column_background_color ) {
		set_theme_mod( 'magazinex_footer_column_background', $footer_column_background_color );
	}

	if ( '' !== $footer_column_headings_color ) {
		set_theme_mod( 'magazinex_footer_column_headings_color', $footer_column_headings_color );
	}

	if ( 'mzx-grid-cols--3' === $footer_column_layout ) {
		set_theme_mod( 'magazinex_footer_column_layout_1_style', 'style-3' );
	} elseif ( 'mzx-grid-cols--2' === $footer_column_layout ) {
		set_theme_mod( 'magazinex_footer_column_layout_1_style', 'style-2' );
	} elseif ( 'mzx-grid-cols--1' === $footer_column_layout ) {
		set_theme_mod( 'magazinex_footer_column_layout_1_style', 'style-1' );
	}

	if ( '' !== $inside_container_background_color ) {
		set_theme_mod( 'magazinex_inside_container_background', $inside_container_background_color );
	}

	if ( 0 !== $enable_drawer ) {
		set_theme_mod( 'magazinex_enable_header_drawer_toggle', 1 );
	}

	if ( '' !== $drawer_content_background_color ) {
		set_theme_mod( 'magazinex_header_drawer_content_background', $drawer_content_background_color );
	}
	if ( 'layout-1' !== $main_header_layout ) {
		set_theme_mod( 'magazinex_main_header_layout', $main_header_layout );
	}

	if ( '#FFFFFF' !== $main_header_background ) {
		set_theme_mod( 'magazinex_main_header_background', $main_header_background );
	}

	if ( 'none' === $enable_pagination ) {
		set_theme_mod( 'magazinex_enable_pagination', false );
	}

	if ( 'default' === $pagination_layout ) {
		set_theme_mod( 'magazinex_pagination_layout', 'layout-1' );
	} else {
		set_theme_mod( 'magazinex_pagination_layout', 'layout-2' );
	}

	if ( true !== $enable_breadcrumb ) {
		set_theme_mod( 'magazinex_enable_breadcrumb', false );
	}

	if ( 1 !== $enable_header_search ) {
		set_theme_mod( 'magazinex_enable_header_search', false );
	}

	if ( '' !== $logo_height ) {
		set_theme_mod( 'magazinex_logo_height', $logo_height );
	}

	// Remove prev theme mods.
	$prev_theme_mod_settings = array(
		'magazinex_footer_bar_bg_color',
		'magazinex_footer_column_layout',
		'magazinex_inside_container_bg_color',
		'magazinex_drawer_background_color',
		'magazinex_primary_header_layout',
		'magazinex_primary_header_background',
		'magazinex_pagination_style',
		'magazinex_enable_breadcrumbs',
		'magazinex_site_logo_height',
		'magazinex_enable_drawer_menu',
		'magazinex_enable_search',
	);

	// Loop through prev theme mods to remove them.
	foreach ( $prev_theme_mod_settings as $prev_theme_mod_setting ) {
		remove_theme_mod( $prev_theme_mod_setting );
	}

	// Set flag to not repeat the migration process, ie, run it only once.
	update_option( 'magazinex_customizer_migration_v1', 1 );

	// Set flag for demo import migration to not repeat the migration process, ie, run it only once.
	if ( $demo_import_migration ) {
		update_option( 'magazinex_demo_import_migration_notice_dismiss', true );
	}

}

add_action( 'after_setup_theme', 'magazinex_customizer_migration_v1' );
