<?php
/**
 * MagazineX svg icons class
 *
 * @package MagazineX
 * @since 1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit();

if ( ! class_exists( 'MagazineX_SVG_Icons' ) ) {

	/**
	 * Class MagazineX_SVG_Icons
	 */
	class MagazineX_SVG_Icons {

		/**
		 * Allowed HTML.
		 *
		 * @var bool[][]
		 */
		public static $allowed_html = array(
			'svg'     => array(
				'class'       => true,
				'xmlns'       => true,
				'width'       => true,
				'height'      => true,
				'viewbox'     => true,
				'aria-hidden' => true,
				'role'        => true,
				'focusable'   => true,
			),
			'path'    => array(
				'fill'      => true,
				'fill-rule' => true,
				'd'         => true,
				'transform' => true,
			),
			'circle'  => array(
				'cx' => true,
				'cy' => true,
				'r'  => true,
			),
			'polygon' => array(
				'fill'      => true,
				'fill-rule' => true,
				'points'    => true,
				'transform' => true,
				'focusable' => true,
			),
		);


		/**
		 * Get the SVG icon.
		 *
		 * @param string $icon Default is empty.
		 * @param bool   $echo Default is true.
		 * @param array  $args Default is empty.
		 * @return string|null
		 */
		public static function get_svg( $icon = '', $echo = true, $args = array() ) {

			$icons = self::get_icons();
			$atts  = '';
			$svg   = '';

			if ( ! empty( $args ) ) {

				foreach ( $args as $key => $value ) {

					if ( ! empty( $value ) ) {
						$atts .= esc_html( $key ) . '="' . esc_attr( $value ) . '" ';
					}
				}
			}

			if ( array_key_exists( $icon, $icons ) ) {
				$repl = sprintf( '<svg class="mzx-icon mzx-icon--%1$s" %2$s', $icon, $atts );
				$svg  = preg_replace( '/^<svg /', $repl, trim( $icons[ $icon ] ) );
				$svg  = preg_replace( "/([\n\t]+)/", ' ', $svg );
				$svg  = preg_replace( '/>\s*</', '><', $svg );
			}

			if ( ! $svg ) {
				return null;
			}

			if ( $echo ) {
				echo wp_kses( $svg, self::$allowed_html );
			} else {
				return wp_kses( $svg, self::$allowed_html );
			}
		}

		/**
		 * Get all SVG icons.
		 *
		 * @return mixed|void
		 */
		public static function get_icons() {
			return apply_filters( 'magazinex_svg_icons', self::$icons );
		}

		/**
		 * SVG icons.
		 *
		 * @var string[]
		 */
		public static $icons = array(
			'cloud-moon-rain' => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M14.604 10.57c-.287-1.743-1.637-3.07-3.27-3.07-.513 0-.996.14-1.43.375C9.18 6.745 8.004 6 6.667 6c-2.209 0-4 2.016-4 4.5 0 .023.008.052.008.075C1.15 10.917 0 12.431 0 14.25 0 16.322 1.492 18 3.333 18H14c1.842 0 3.333-1.678 3.333-3.75 0-1.838-1.175-3.36-2.729-3.68zm9.059-.08c-2.934.624-5.625-1.888-5.625-5.193 0-1.903.912-3.656 2.395-4.599.23-.145.171-.534-.087-.585A5.455 5.455 0 0019.242 0c-3.246 0-5.88 2.869-6.017 6.464 1.113.558 2.008 1.584 2.454 2.892 1.546.67 2.667 2.222 2.925 4.069.213.023.417.07.634.07 1.862 0 3.566-.947 4.691-2.498.175-.225-.008-.563-.266-.506zm-8.476 9.108c-.316-.201-.724-.084-.908.282l-1.525 3c-.183.36-.07.815.25 1.022a.615.615 0 00.33.098.66.66 0 00.579-.38l1.524-3c.18-.36.071-.815-.25-1.022zm-4 0c-.316-.201-.724-.084-.908.282l-1.525 3c-.183.36-.07.815.25 1.022a.615.615 0 00.33.098.66.66 0 00.579-.38l1.524-3c.18-.36.071-.815-.25-1.022zm-4 0c-.316-.201-.724-.084-.908.282l-1.525 3c-.183.36-.07.815.25 1.022a.615.615 0 00.33.098.66.66 0 00.579-.38l1.524-3c.18-.36.071-.815-.25-1.022zm-4 0c-.316-.201-.724-.084-.908.282l-1.525 3c-.183.36-.07.815.25 1.022a.615.615 0 00.33.098.66.66 0 00.579-.38l1.524-3c.18-.36.071-.815-.25-1.022z" /><defs><linearGradient id="prefix__paint0_linear_3567_430" x1="4.743" y1="0" x2="25.339" y2=".071" gradientUnits="userSpaceOnUse"><stop stop-color="#BA81FF"/><stop offset="1" stop-color="#FF6A95" /></linearGradient></defs></svg>',
			'flash'           => '<svg xmlns="http://www.w3.org/2000/svg"><path d="M8.90179 4.33928C9.00893 4.45833 9.02976 4.58929 8.96429 4.73214L4.14286 15.0625C4.06548 15.2113 3.94048 15.2857 3.76786 15.2857C3.74405 15.2857 3.70238 15.2798 3.64286 15.2679C3.54167 15.2381 3.46429 15.1815 3.41071 15.0982C3.3631 15.0149 3.35119 14.9256 3.375 14.8304L5.13393 7.61607L1.50893 8.51786C1.48512 8.52381 1.4494 8.52679 1.40179 8.52679C1.29464 8.52679 1.20238 8.49405 1.125 8.42857C1.01786 8.33929 0.979167 8.22321 1.00893 8.08036L2.80357 0.714285C2.82738 0.630952 2.875 0.562499 2.94643 0.508928C3.01786 0.455357 3.10119 0.428571 3.19643 0.428571H6.125C6.2381 0.428571 6.33333 0.467261 6.41071 0.544642C6.4881 0.616071 6.52679 0.70238 6.52679 0.803571C6.52679 0.85119 6.5119 0.904761 6.48214 0.964285L4.95536 5.09821L8.49107 4.22321C8.53869 4.21131 8.57441 4.20536 8.59821 4.20536C8.71131 4.20536 8.8125 4.25 8.90179 4.33928Z" /></svg>',
			'caret-down'      => '<svg xmlns="http://www.w3.org/2000/svg"><path d="M7.29.424c.093.091.139.2.139.326a.446.446 0 01-.138.326l-3.25 3.25a.446.446 0 01-.327.138.446.446 0 01-.326-.138l-3.25-3.25A.446.446 0 010 .75C0 .624.046.515.138.424A.446.446 0 01.464.286h6.5c.126 0 .235.046.327.138z" /></svg>',
			'facebook'        => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M17.712 1.159v3.49h-2.076c-.758 0-1.27.159-1.534.476-.264.317-.396.793-.396 1.428v2.499h3.873l-.515 3.913h-3.358V23H9.66V12.965H6.289V9.052H9.66V6.169c0-1.639.458-2.908 1.375-3.807C11.952 1.454 13.172 1 14.697 1c1.296 0 2.3.053 3.015.159z" /></svg>',
			'twitter'         => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M23 5.188a9.448 9.448 0 01-2.261 2.331 12.882 12.882 0 01-.517 4.216 12.997 12.997 0 01-1.62 3.462 13.625 13.625 0 01-2.568 2.945c-.995.847-2.196 1.526-3.601 2.038-1.405.503-2.908.754-4.51.754-2.521 0-4.83-.675-6.923-2.024.326.037.689.056 1.089.056 2.094 0 3.96-.642 5.598-1.927a4.421 4.421 0 01-2.625-.893 4.448 4.448 0 01-1.591-2.234c.307.047.59.07.851.07.4 0 .796-.05 1.187-.153a4.48 4.48 0 01-2.597-1.55 4.402 4.402 0 01-1.019-2.875v-.056a4.473 4.473 0 002.038.572 4.504 4.504 0 01-1.465-1.605 4.393 4.393 0 01-.545-2.15c0-.819.205-1.577.615-2.275A12.888 12.888 0 006.64 7.226c1.619.828 3.35 1.289 5.192 1.382a5.005 5.005 0 01-.111-1.033c0-1.247.437-2.308 1.312-3.183.884-.884 1.95-1.326 3.197-1.326 1.303 0 2.4.475 3.294 1.424A8.841 8.841 0 0022.386 3.4c-.345 1.07-1.005 1.899-1.982 2.485A8.985 8.985 0 0023 5.188z" /></svg>',
			'linkedin'        => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M5.999 8.319v14.194H1.272V8.319H6zm.3-4.383c.01.697-.233 1.28-.73 1.748-.487.467-1.131.701-1.934.701h-.028c-.783 0-1.413-.234-1.89-.701C1.238 5.216 1 4.634 1 3.936c0-.706.243-1.289.73-1.747.497-.468 1.142-.702 1.934-.702.793 0 1.428.234 1.905.702.477.458.72 1.04.73 1.747zM23 14.378v8.135h-4.712v-7.591c0-1.003-.196-1.786-.587-2.35-.382-.572-.984-.858-1.805-.858-.602 0-1.108.167-1.518.5-.401.325-.702.731-.903 1.218-.105.287-.157.673-.157 1.16v7.921H8.605c.02-3.81.03-6.899.03-9.267 0-2.368-.006-3.781-.015-4.24l-.015-.687h4.713v2.063h-.029c.191-.306.387-.573.587-.803.2-.229.468-.477.802-.744.344-.268.76-.473 1.246-.616a5.583 5.583 0 011.648-.23c1.632 0 2.945.545 3.938 1.633.993 1.08 1.49 2.664 1.49 4.756z" /></svg>',
			'youtube'         => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M9.729 14.848l5.942-3.069-5.942-3.106v6.175zM12 4.266c1.375 0 2.7.02 3.977.061 1.285.033 2.226.07 2.824.11l.896.05c.008 0 .078.008.209.025.13.008.225.02.282.036.057.009.152.025.283.05.139.024.257.057.355.098a5.6 5.6 0 01.344.16c.131.065.258.147.38.245.124.09.242.196.357.319.049.05.11.127.184.233.082.098.2.336.356.712.164.377.274.79.331 1.24.066.524.115 1.085.148 1.682.04.59.065 1.052.073 1.387v2.161a25.985 25.985 0 01-.22 3.56c-.058.45-.16.86-.308 1.227-.147.36-.278.61-.392.75l-.172.208a3.356 3.356 0 01-.356.331c-.123.09-.25.168-.38.234-.132.057-.246.106-.345.147a1.7 1.7 0 01-.355.098c-.131.025-.23.045-.295.062l-.282.036-.197.013c-2.054.155-4.62.233-7.697.233-1.694-.016-3.167-.041-4.42-.074-1.243-.04-2.062-.073-2.455-.098l-.601-.049-.442-.05a6.194 6.194 0 01-.675-.122 4.074 4.074 0 01-.626-.258 2.484 2.484 0 01-.688-.503 3.497 3.497 0 01-.196-.221c-.074-.106-.193-.348-.356-.724a4.832 4.832 0 01-.32-1.24 30.55 30.55 0 01-.159-1.67 49.154 49.154 0 01-.061-1.4v-2.16a25.992 25.992 0 01.22-3.56c.058-.45.16-.855.307-1.215.148-.368.279-.622.393-.761l.172-.209c.115-.123.233-.23.356-.32.123-.097.25-.18.38-.245.132-.065.246-.118.344-.16a1.72 1.72 0 01.344-.097c.14-.025.238-.041.295-.05a1.48 1.48 0 01.282-.036c.131-.017.2-.025.209-.025 2.054-.147 4.62-.221 7.697-.221z" /></svg>',
			'plus'            => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path clip-rule="evenodd" d="M12.915 3.5a1 1 0 10-2 0v8.084H3a1 1 0 000 2h7.915V21.5a1 1 0 102 0v-7.916H21a1 1 0 100-2h-8.085V3.5z"/></svg>',
			'menu-close'      => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path fill-rule="evenodd" clip-rule="evenodd" d="M6.343 5.013a1 1 0 00-1.414 1.414l5.656 5.657-5.656 5.657a1 1 0 101.414 1.414L12 13.498l5.657 5.657a1 1 0 001.414-1.414l-5.657-5.657 5.657-5.657a1 1 0 00-1.414-1.414L12 10.67 6.343 5.013z" /></svg>',
			'chevron-right'   => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M15.707 11.293a1 1 0 010 1.414l-6 6a1 1 0 01-1.414-1.414L13.586 12 8.293 6.707a1 1 0 011.414-1.414l6 6z" /></svg>',
			'chevron-left'    => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M8.293 12.707a1 1 0 010-1.414l6-6a1 1 0 111.414 1.414L10.414 12l5.293 5.293a1 1 0 01-1.414 1.414l-6-6z"/></svg>',
			'cart'            => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 27 27"><path fill-rule="evenodd" clip-rule="evenodd" d="M1.05261 0.880524C0.500328 0.880524 0.0526123 1.32824 0.0526123 1.88052C0.0526123 2.43281 0.500328 2.88052 1.05261 2.88052H3.63131L4.60679 7.74865C4.6114 7.7787 4.61736 7.80832 4.62458 7.83743L6.5369 17.3808L6.53703 17.3815C6.68761 18.1379 7.09965 18.8172 7.70075 19.3005C8.2993 19.7818 9.04739 20.0383 9.81512 20.0261H20.9209C21.6886 20.0383 22.4367 19.7818 23.0353 19.3005C23.6365 18.817 24.0486 18.1375 24.1991 17.3808L24.1991 17.3808L24.2006 17.3733L26.0315 7.78324C26.0874 7.49047 26.0098 7.18802 25.8199 6.95834C25.6299 6.72866 25.3474 6.5957 25.0493 6.5957H6.41552L5.43132 1.68405C5.33769 1.21679 4.92735 0.880524 4.45081 0.880524H1.05261ZM8.4982 16.9893L6.81628 8.5957H23.8403L22.2375 16.9907L22.2369 16.994C22.1775 17.2884 22.0167 17.5531 21.782 17.7419C21.5464 17.9313 21.2514 18.032 20.9487 18.0262L20.9296 18.0261H9.80641L9.78727 18.0262C9.48456 18.032 9.18959 17.9313 8.95401 17.7419C8.71845 17.5525 8.55731 17.2865 8.49849 16.9907L8.4982 16.9893ZM9.02717 24.5888C8.94934 24.5888 8.88281 24.6526 8.88281 24.7355C8.88281 24.8184 8.94934 24.8822 9.02717 24.8822C9.105 24.8822 9.17153 24.8184 9.17153 24.7355C9.17153 24.6526 9.105 24.5888 9.02717 24.5888ZM6.88281 24.7355C6.88281 23.5518 7.84098 22.5888 9.02717 22.5888C10.2134 22.5888 11.1715 23.5518 11.1715 24.7355C11.1715 25.9192 10.2134 26.8822 9.02717 26.8822C7.84098 26.8822 6.88281 25.9192 6.88281 24.7355ZM21.6153 24.5888C21.5374 24.5888 21.4709 24.6526 21.4709 24.7355C21.4709 24.8184 21.5374 24.8822 21.6153 24.8822C21.6931 24.8822 21.7596 24.8184 21.7596 24.7355C21.7596 24.6526 21.6931 24.5888 21.6153 24.5888ZM19.4709 24.7355C19.4709 23.5518 20.4291 22.5888 21.6153 22.5888C22.8015 22.5888 23.7596 23.5518 23.7596 24.7355C23.7596 25.9192 22.8015 26.8822 21.6153 26.8822C20.4291 26.8822 19.4709 25.9192 19.4709 24.7355Z" /></svg>',
			'user'            => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M12 2a5 5 0 100 10 5 5 0 000-10zM9 7a3 3 0 116 0 3 3 0 01-6 0z" /><path d="M7.5 14c-1.423 0-2.808.502-3.846 1.424C2.612 16.35 2 17.634 2 19v2a1 1 0 102 0v-2c0-.755.336-1.507.982-2.081C5.632 16.341 6.536 16 7.5 16h9c.964 0 1.868.341 2.518.919.646.574.982 1.326.982 2.081v2a1 1 0 102 0v-2c0-1.367-.612-2.65-1.654-3.576C19.308 14.502 17.923 14 16.5 14h-9z"/></svg>',
			'search'          => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M14.486 14.499c1.163-1.164 1.745-2.56 1.745-4.191 0-1.63-.582-3.024-1.745-4.178-1.155-1.164-2.548-1.745-4.178-1.745S7.28 4.966 6.117 6.13c-1.155 1.154-1.732 2.547-1.732 4.178 0 1.63.577 3.027 1.732 4.19 1.163 1.155 2.56 1.733 4.19 1.733 1.631 0 3.024-.578 4.179-1.732zM23 21.308c0 .458-.168.855-.502 1.19a1.626 1.626 0 01-1.19.502c-.476 0-.873-.168-1.19-.502l-4.535-4.522c-1.578 1.093-3.336 1.64-5.275 1.64a9.265 9.265 0 01-3.623-.728 9.554 9.554 0 01-2.975-1.983 9.554 9.554 0 01-1.983-2.975A9.266 9.266 0 011 10.308c0-1.26.242-2.464.727-3.61.494-1.154 1.155-2.146 1.983-2.974A9.259 9.259 0 016.685 1.74 9.123 9.123 0 0110.308 1c1.26 0 2.463.247 3.61.74a9.07 9.07 0 012.974 1.984 9.07 9.07 0 011.983 2.974 9.028 9.028 0 01.74 3.61c0 1.939-.546 3.697-1.639 5.275l4.535 4.535c.326.326.489.723.489 1.19z"/></svg>',
			'calender'        => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M2.692 21.429h18.616V8.857H2.692V21.43zM7.77 6.5V2.964a.368.368 0 00-.119-.282.43.43 0 00-.304-.11H6.5a.43.43 0 00-.304.11.368.368 0 00-.12.282V6.5c0 .115.04.209.12.282.08.074.18.11.304.11h.846a.43.43 0 00.304-.11.368.368 0 00.12-.282zm10.154 0V2.964a.368.368 0 00-.119-.282.43.43 0 00-.304-.11h-.846a.429.429 0 00-.304.11.368.368 0 00-.12.282V6.5c0 .115.04.209.12.282.08.074.18.11.304.11h.846a.43.43 0 00.304-.11.368.368 0 00.12-.282zM23 5.714V21.43c0 .425-.168.794-.502 1.105a1.69 1.69 0 01-1.19.466H2.692a1.69 1.69 0 01-1.19-.466C1.167 22.224 1 21.855 1 21.43V5.714c0-.425.167-.794.502-1.105a1.69 1.69 0 011.19-.466h1.693V2.964c0-.54.207-1.002.621-1.387A2.118 2.118 0 016.5 1h.846c.582 0 1.08.192 1.494.577.414.385.622.847.622 1.387v1.179h5.077V2.964c0-.54.207-1.002.62-1.387A2.118 2.118 0 0116.655 1h.846c.582 0 1.08.192 1.494.577.414.385.621.847.621 1.387v1.179h1.693c.458 0 .855.155 1.19.466.334.311.502.68.502 1.105z"/></svg>',
			'edit'            => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path fill-rule="evenodd" d="M17.207 4.207a1.121 1.121 0 011.586 1.586L6.489 18.097l-2.115.529.529-2.115L17.207 4.207zM18 1.88c-.828 0-1.622.329-2.207.914l-12.5 12.5a1 1 0 00-.263.464l-1 4a1 1 0 001.213 1.213l4-1a1 1 0 00.464-.263l12.5-12.5a3.12 3.12 0 00-1.012-5.09A3.121 3.121 0 0018 1.878zM12 19a1 1 0 100 2h9a1 1 0 100-2h-9z" /></svg>',
			'comment'         => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path fill-rule="evenodd" d="M12 4c-5.19 0-9 3.33-9 7 0 1.756.84 3.401 2.308 4.671l.412.358-.46 3.223 3.456-1.728.367.098c.913.245 1.893.378 2.917.378 5.19 0 9-3.33 9-7s-3.81-7-9-7zM1 11c0-5.167 5.145-9 11-9s11 3.833 11 9-5.145 9-11 9c-1.06 0-2.087-.122-3.06-.352l-6.2 3.1.849-5.94C1.999 15.266 1 13.246 1 11z" /></svg>',
			'arrow-right'     => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M4 12a1 1 0 011-1h14a1 1 0 110 2H5a1 1 0 01-1-1z" clip-rule="evenodd"/><path d="M11.293 4.293a1 1 0 011.414 0l7 7a1 1 0 010 1.414l-7 7a1 1 0 01-1.414-1.414L17.586 12l-6.293-6.293a1 1 0 010-1.414z" clip-rule="evenodd"/></svg>',
			'arrow-down'      => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path fill-rule="evenodd" clip-rule="evenodd" d="m6 7.879 6 6 6-6L20.122 10 12 18.121 3.88 10 6 7.879Z" /></svg>',
			'arrow-up'        => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path fill-rule="evenodd" d="M12 20a1 1 0 01-1-1V5a1 1 0 112 0v14a1 1 0 01-1 1z"></path><path fill-rule="evenodd" d="M4.293 12.707a1 1 0 010-1.414l7-7a1 1 0 011.414 0l7 7a1 1 0 01-1.414 1.414L12 6.414l-6.293 6.293a1 1 0 01-1.414 0z"></path></svg>',
			'filter'          => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path clip-rule="evenodd" d="M4 2a1 1 0 011 1v7a1 1 0 11-2 0V3a1 1 0 011-1zm1 13h2a1 1 0 100-2H1a1 1 0 100 2h2v6a1 1 0 102 0v-6zm8-3a1 1 0 10-2 0v9a1 1 0 102 0v-9zM12 2a1 1 0 011 1v4h2a1 1 0 110 2H9a1 1 0 110-2h2V3a1 1 0 011-1zm8 13h3a1 1 0 110 2h-2v4a1 1 0 11-2 0v-4h-2a1 1 0 110-2h3zm0-13a1 1 0 011 1v9a1 1 0 11-2 0V3a1 1 0 011-1z"/></svg>',
			'tag'             => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M2 1a1 1 0 00-1 1v10a1 1 0 00.293.707l8.59 8.58a2.999 2.999 0 004.244 0l7.17-7.17-.707-.707.71.705a3 3 0 000-4.23l-.003-.002-8.59-8.59A1 1 0 0012 1H2zm17.882 11.704l-.001.001-7.168 7.168a1 1 0 01-1.415 0h-.001L3 11.584V3h8.586l8.295 8.295a1 1 0 010 1.41zM7 6a1 1 0 000 2h.01a1 1 0 000-2H7z" /></svg>',
			'close'           => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M5.293 5.293a1 1 0 011.414 0L12 10.586l5.293-5.293a1 1 0 111.414 1.414L13.414 12l5.293 5.293a1 1 0 01-1.414 1.414L12 13.414l-5.293 5.293a1 1 0 01-1.414-1.414L10.586 12 5.293 6.707a1 1 0 010-1.414z" /></svg>',
			'drawer'          => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path fill-rule="evenodd" d="M2 8a1 1 0 011-1h18a1 1 0 110 2H3a1 1 0 01-1-1zm0 8a1 1 0 011-1h7a1 1 0 110 2H3a1 1 0 01-1-1zm1-5a1 1 0 100 2h13a1 1 0 100-2H3z" clip-rule="evenodd"/></svg>',
			'close-circle'    => '<svg xmlns="http://www.w3.org/2000/svg"><path d="M11.796 10.84a.66.66 0 010 .956.737.737 0 01-.478.204.737.737 0 01-.477-.204L6 6.955l-4.84 4.84A.737.737 0 01.681 12a.737.737 0 01-.477-.204.66.66 0 010-.955L5.045 6 .205 1.16a.66.66 0 010-.955.66.66 0 01.954 0L6 5.045l4.84-4.84a.66.66 0 01.956 0 .66.66 0 010 .954L6.955 6l4.84 4.84z" /></svg>',
		);
	}
}
