<?php
/**
 * Class to include Blog customize options.
 *
 * Class MagazineX_Customize_Blog_Options
 *
 * @package    MagazineX
 * @since      1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * Class to include Blog customize options.
 *
 * Class MagazineX_Customize_Blog_Options
 */
class MagazineX_Customize_Blog_Options extends MagazineX_Customize_Base_Option {

	/**
	 * Include customize options.
	 *
	 * @param array                 $options      Customize options provided via the theme.
	 * @param \WP_Customize_Manager $wp_customize Theme Customizer object.
	 *
	 * @return mixed|void Customizer options for registering panels, sections as well as controls.
	 */
	public function register_options( $options, $wp_customize ) {

		$configs = array(
			array(
				'name'     => 'magazinex_pagination_layout_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'Pagination', 'magazinex' ),
				'section'  => 'magazinex_blog_section',
				'priority' => 110,
			),

			array(
				'name'     => 'magazinex_enable_pagination',
				'default'  => true,
				'type'     => 'control',
				'control'  => 'magazinex-toggle',
				'label'    => esc_html__( 'Enable', 'magazinex' ),
				'section'  => 'magazinex_blog_section',
				'priority' => 120,
			),

			array(
				'name'     => 'magazinex_pagination_layout',
				'default'  => 'layout-1',
				'type'     => 'control',
				'control'  => 'select',
				'label'    => esc_html__( 'Layout', 'magazinex' ),
				'section'  => 'magazinex_blog_section',
				'priority' => 130,
				'choices'  => array(
					'layout-1' => esc_html__( 'Next/Prev', 'magazinex' ),
					'layout-2' => esc_html__( 'Numbered', 'magazinex' ),
				),
			),
		);

		$options = array_merge( $options, $configs );

		return $options;
	}

}

return new MagazineX_Customize_Blog_Options();
