<?php
/**
 * Class to include footer bar customize options.
 *
 * Class MagazineX_Customize_Footer_Bar_Options
 *
 * @package    MagazineX
 * @since      1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * Class to include footer bar customize options.
 *
 * Class MagazineX_Customize_Footer_Bar_Options
 */
class MagazineX_Customize_Footer_Bar_Options extends MagazineX_Customize_Base_Option {

	/**
	 * Include customize options.
	 *
	 * @param array                 $options      Customize options provided via the theme.
	 * @param \WP_Customize_Manager $wp_customize Theme Customizer object.
	 *
	 * @return mixed|void Customizer options for registering panels, sections as well as controls.
	 */
	public function register_options( $options, $wp_customize ) {

		$configs = array(

			array(
				'name'     => 'magazinex_footer_bar_general_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'General', 'magazinex' ),
				'section'  => 'magazinex_footer_bar_section',
				'priority' => 10,
			),

			array(
				'name'     => 'magazinex_footer_bar_background_group',
				'label'    => esc_html__( 'Background', 'magazinex' ),
				'default'  => '',
				'type'     => 'control',
				'control'  => 'magazinex-group',
				'section'  => 'magazinex_footer_bar_section',
				'priority' => 20,
			),

			array(
				'name'     => 'magazinex_footer_bar_background',
				'default'  => '',
				'type'     => 'sub-control',
				'control'  => 'magazinex-color',
				'parent'   => 'magazinex_footer_bar_background_group',
				'label'    => 'Background',
				'section'  => 'magazinex_footer_bar_section',
				'priority' => 20,
			),

			array(
				'name'     => 'magazinex_footer_bar_text_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'Text', 'magazinex' ),
				'section'  => 'magazinex_footer_bar_section',
				'priority' => 30,
			),

			array(
				'name'     => 'magazinex_footer_bar_text_color_group',
				'label'    => esc_html__( 'Color', 'magazinex' ),
				'default'  => '',
				'type'     => 'control',
				'control'  => 'magazinex-group',
				'section'  => 'magazinex_footer_bar_section',
				'priority' => 40,
			),

			array(
				'name'     => 'magazinex_footer_bar_text_color',
				'default'  => '',
				'type'     => 'sub-control',
				'control'  => 'magazinex-color',
				'parent'   => 'magazinex_footer_bar_text_color_group',
				'section'  => 'magazinex_footer_bar_section',
				'priority' => 40,
			),

			array(
				'name'     => 'magazinex_footer_bar_link_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'Link', 'magazinex' ),
				'section'  => 'magazinex_footer_bar_section',
				'priority' => 50,
			),

			array(
				'name'     => 'magazinex_footer_bar_link_color_group',
				'label'    => esc_html__( 'Color', 'magazinex' ),
				'default'  => '',
				'type'     => 'control',
				'control'  => 'magazinex-group',
				'section'  => 'magazinex_footer_bar_section',
				'priority' => 60,
			),

			array(
				'name'     => 'magazinex_footer_bar_link_color',
				'default'  => '',
				'type'     => 'sub-control',
				'control'  => 'magazinex-color',
				'parent'   => 'magazinex_footer_bar_link_color_group',
				'tab'      => esc_html__( 'Normal', 'magazinex' ),
				'section'  => 'magazinex_footer_bar_section',
				'priority' => 60,
			),

			array(
				'name'     => 'magazinex_footer_bar_link_hover_color',
				'label'    => esc_html__( 'Color', 'magazinex' ),
				'default'  => '',
				'type'     => 'sub-control',
				'control'  => 'magazinex-color',
				'parent'   => 'magazinex_footer_bar_link_color_group',
				'tab'      => esc_html__( 'Hover', 'magazinex' ),
				'section'  => 'magazinex_footer_bar_section',
				'priority' => 60,
			),
		);

		$options = array_merge( $options, $configs );

		return $options;
	}
}

return new MagazineX_Customize_Footer_Bar_Options();
