<?php
/**
 * Class to include footer column customize options.
 *
 * Class MagazineX_Customize_Footer_Column_Options
 *
 * @package    MagazineX
 * @since      1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * Class to include footer column customize options.
 *
 * Class MagazineX_Customize_Footer_Column_Options
 */
class MagazineX_Customize_Footer_Column_Options extends MagazineX_Customize_Base_Option {

	/**
	 * Include customize options.
	 *
	 * @param array                 $options      Customize options provided via the theme.
	 * @param \WP_Customize_Manager $wp_customize Theme Customizer object.
	 *
	 * @return mixed|void Customizer options for registering panels, sections as well as controls.
	 */
	public function register_options( $options, $wp_customize ) {

		$configs = array(
			array(
				'name'     => 'magazinex_footer_column_general_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'General', 'magazinex' ),
				'section'  => 'magazinex_footer_column_section',
				'priority' => 10,
			),

			array(
				'name'       => 'magazinex_footer_column_layout_1_style',
				'default'    => 'style-3',
				'type'       => 'control',
				'label'      => esc_html__( 'Style', 'magazinex' ),
				'control'    => 'magazinex-radio-image',
				'section'    => 'magazinex_footer_column_section',
				'choices'    => array(
					'style-1' => array(
						'label' => 'One Column',
						'url'   => MAGAZINEX_ADMIN_IMAGES_URL . '/column-1.png',
					),
					'style-2' => array(
						'label' => '',
						'url'   => MAGAZINEX_ADMIN_IMAGES_URL . '/column-2.png',
					),
					'style-3' => array(
						'label' => '',
						'url'   => MAGAZINEX_ADMIN_IMAGES_URL . '/column-3.png',
					),
				),
				'dependency' => array(
					'magazinex_footer_column_layout',
					'==',
					'layout-1',
				),
				'priority'   => 30,
			),

			array(
				'name'       => 'magazinex_footer_column_background_group',
				'label'      => esc_html__( 'Background', 'magazinex' ),
				'default'    => '',
				'type'       => 'control',
				'control'    => 'magazinex-group',
				'section'    => 'magazinex_footer_column_section',
				'dependency' => array(
					'magazinex_footer_column_layout',
					'==',
					'layout-1',
				),
				'priority'   => 40,
			),

			array(
				'name'       => 'magazinex_footer_column_background',
				'label'      => esc_html__( 'Color', 'magazinex' ),
				'default'    => '',
				'type'       => 'sub-control',
				'control'    => 'magazinex-color',
				'parent'     => 'magazinex_footer_column_background_group',
				'section'    => 'magazinex_footer_column_section',
				'dependency' => array(
					'magazinex_footer_column_layout',
					'==',
					'layout-1',
				),
				'priority'   => 40,
			),

			array(
				'name'          => 'magazinex_navigate_footer_columns',
				'type'          => 'control',
				'control'       => 'magazinex-navigate',
				'section'       => 'magazinex_footer_column_section',
				'navigate_info' => array(
					'target_container' => 'section',
					'target_id'        => 'sidebar-widgets-mzx-footer-col-1',
					'target_label'     => esc_html__( 'Footer Column', 'magazinex' ),
				),
				'priority'      => 70,
			),

			array(
				'name'     => 'magazinex_footer_column_headings_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'Headings', 'magazinex' ),
				'section'  => 'magazinex_footer_column_section',
				'priority' => 80,
			),

			array(
				'name'     => 'magazinex_footer_column_headings_color_group',
				'label'    => esc_html__( 'Color', 'magazinex' ),
				'default'  => '',
				'type'     => 'control',
				'control'  => 'magazinex-group',
				'section'  => 'magazinex_footer_column_section',
				'priority' => 90,
			),

			array(
				'name'     => 'magazinex_footer_column_headings_color',
				'default'  => '',
				'type'     => 'sub-control',
				'control'  => 'magazinex-color',
				'parent'   => 'magazinex_footer_column_headings_color_group',
				'section'  => 'magazinex_footer_column_section',
				'priority' => 100,
			),

			array(
				'name'     => 'magazinex_footer_column_text_heading',
				'label'    => esc_html__( 'Text', 'magazinex' ),
				'default'  => '',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'section'  => 'magazinex_footer_column_section',
				'priority' => 110,
			),

			array(
				'name'     => 'magazinex_footer_column_text_color_group',
				'label'    => esc_html__( 'Text', 'magazinex' ),
				'default'  => '',
				'type'     => 'control',
				'control'  => 'magazinex-group',
				'section'  => 'magazinex_footer_column_section',
				'priority' => 120,
			),

			array(
				'name'     => 'magazinex_footer_column_text_color',
				'default'  => '',
				'type'     => 'sub-control',
				'control'  => 'magazinex-color',
				'label'    => esc_html__( 'Color', 'magazinex' ),
				'parent'   => 'magazinex_footer_column_text_color_group',
				'section'  => 'magazinex_footer_column_section',
				'priority' => 120,
			),

			array(
				'name'     => 'magazinex_footer_column_link_heading',
				'label'    => esc_html__( 'Links', 'magazinex' ),
				'default'  => '',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'section'  => 'magazinex_footer_column_section',
				'priority' => 130,
			),

			array(
				'name'     => 'magazinex_footer_column_link_color_group',
				'label'    => esc_html__( 'Color', 'magazinex' ),
				'default'  => '',
				'type'     => 'control',
				'control'  => 'magazinex-group',
				'section'  => 'magazinex_footer_column_section',
				'priority' => 140,
			),

			array(
				'name'     => 'magazinex_footer_column_link_color',
				'default'  => '',
				'type'     => 'sub-control',
				'control'  => 'magazinex-color',
				'parent'   => 'magazinex_footer_column_link_color_group',
				'section'  => 'magazinex_footer_column_section',
				'priority' => 150,
			),

		);

		$options = array_merge( $options, $configs );

		return $options;
	}
}

return new MagazineX_Customize_Footer_Column_Options();
