<?php
/**
 * Customize container options.
 *
 * @package MagazineX
 * @since   TBD
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'MagazineX_Customize_Container_Options' ) ) :

	/**
	 * Class to include Colors customize options.
	 *
	 * Class MagazineX_Customize_Container_Options
	 */
	class MagazineX_Customize_Container_Options extends MagazineX_Customize_Base_Option {

		/**
		 * Include customize options.
		 *
		 * @param array $options Customize options provided via the theme.
		 * @param \WP_Customize_Manager $wp_customize Theme Customizer object.
		 *
		 * @return mixed|void Customizer options for registering panels, sections as well as controls.
		 */
		public function register_options( $options, $wp_customize ) {
			$configs = array(

				array(
					'name'     => 'magazinex_container_general_heading',
					'type'     => 'control',
					'control'  => 'magazinex-title',
					'label'    => esc_html__( 'General', 'magazinex' ),
					'section'  => 'magazinex_global_container_section',
					'priority' => 10,
				),

				array(
					'name'     => 'magazinex_inside_container_background_group',
					'type'     => 'control',
					'control'  => 'magazinex-group',
					'label'    => esc_html__( 'Background', 'magazinex' ),
					'section'  => 'magazinex_global_container_section',
					'priority' => 30,
				),

				array(
					'name'     => 'magazinex_inside_container_background',
					'label'    => esc_html__( 'Background Color', 'magazinex' ),
					'default'  => '#F5F9FF',
					'type'     => 'sub-control',
					'control'  => 'magazinex-color',
					'section'  => 'magazinex_global_container_section',
					'parent'   => 'magazinex_inside_container_background_group',
					'priority' => 140,
				),
			);

			$options = array_merge( $options, $configs );

			return $options;
		}
	}

	new MagazineX_Customize_Container_Options();

endif;
