<?php
/**
 * Class to include drawer menu customize options.
 *
 * Class MagazineX_Customize_Drawer_Menu_Options
 *
 * @package    MagazineX
 * @since      1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * Class to include drawer menu customize options.
 *
 * Class MagazineX_Customize_Drawer_Menu_Options
 */
class MagazineX_Customize_Drawer_Menu_Options extends MagazineX_Customize_Base_Option {

	/**
	 * Include customize options.
	 *
	 * @param array                 $options      Customize options provided via the theme.
	 * @param \WP_Customize_Manager $wp_customize Theme Customizer object.
	 *
	 * @return mixed|void Customizer options for registering panels, sections as well as controls.
	 */
	public function register_options( $options, $wp_customize ) {

		$configs = array(

			array(
				'name'     => 'magazinex_drawer_toggle_general_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'General', 'magazinex' ),
				'section'  => 'magazinex_drawer_toggle_section',
				'priority' => 10,
			),

			array(
				'name'     => 'magazinex_enable_header_drawer_toggle',
				'default'  => 0,
				'type'     => 'control',
				'control'  => 'magazinex-toggle',
				'label'    => esc_html__( 'Enable', 'magazinex' ),
				'section'  => 'magazinex_drawer_toggle_section',
				'priority' => 20,
			),

			array(
				'name'          => 'magazinex_drawer_block_info',
				'type'          => 'control',
				'control'       => 'magazinex-navigate',
				'section'       => 'magazinex_drawer_toggle_section',
				'navigate_info' => array(
					'target_container' => 'section',
					'target_id'        => 'sidebar-widgets-mzx-drawer-sidebar',
					'target_label'     => esc_html__( 'Drawer ', 'magazinex' ),
				),
				'dependency'    => array(
					'magazinex_enable_header_drawer_toggle',
					'==',
					true,
				),
				'priority'      => 30,
			),

			array(
				'name'       => 'magazinex_drawer_toggle_content_area_heading',
				'type'       => 'control',
				'control'    => 'magazinex-title',
				'label'      => esc_html__( 'Content Area', 'magazinex' ),
				'section'    => 'magazinex_drawer_toggle_section',
				'dependency' => array(
					'magazinex_enable_header_drawer_toggle',
					'==',
					1,
				),
				'priority'   => 40,
			),

			array(
				'name'       => 'magazinex_header_drawer_content_background',
				'default'    => '',
				'type'       => 'control',
				'control'    => 'magazinex-color',
				'label'      => esc_html__( 'Background Color', 'magazinex' ),
				'section'    => 'magazinex_drawer_toggle_section',
				'priority'   => 50,
				'dependency' => array(
					'magazinex_enable_header_drawer_toggle',
					'==',
					1,
				),
			),

		);

		$options = array_merge( $options, $configs );

		return $options;
	}
}

return new MagazineX_Customize_Drawer_Menu_Options();
