<?php
/**
 * Override default customizer panels, sections, settings or controls.
 *
 * @package    MagazineX
 * @since      1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

// Site Identity.
$wp_customize->get_control( 'custom_logo' )->priority     = 20;
$wp_customize->get_control( 'site_icon' )->priority       = 60;
$wp_customize->get_control( 'blogname' )->priority        = 70;
$wp_customize->get_control( 'blogdescription' )->priority = 110;

// Override Settings.
$wp_customize->get_setting( 'blogname' )->transport        = 'postMessage';
$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

if ( isset( $wp_customize->selective_refresh ) ) {

	$wp_customize->selective_refresh->add_partial(
		'custom_logo',
		array(
			'selector'        => '#mzx-site-branding',
			'render_callback' => 'MagazineX_Customizer_Partials::render_customize_partial_custom_logo',
		)
	);

	$wp_customize->selective_refresh->add_partial(
		'blogname',
		array(
			'selector'        => '.mzx-site-title a',
			'render_callback' => 'MagazineX_Customizer_Partials::render_customize_partial_blogname',
		)
	);

	$wp_customize->selective_refresh->add_partial(
		'blogdescription',
		array(
			'selector'        => '.mzx-site-description',
			'render_callback' => 'MagazineX_Customizer_Partials::render_customize_partial_blogdescription',
		)
	);
}

/**
 * Modify WooCommerce default section, priorities and properties.
 */
if ( class_exists( 'WooCommerce' ) ) {
	$wp_customize->get_panel( 'woocommerce' )->priority                      = 70;
	$wp_customize->get_control( 'woocommerce_catalog_columns' )->section     = 'magazinex_woocommerce_shop_section';
	$wp_customize->get_control( 'woocommerce_catalog_columns' )->label       = esc_html__( 'Products Per Row', 'magazinex' );
	$wp_customize->get_control( 'woocommerce_catalog_columns' )->priority    = 120;
	$wp_customize->get_control( 'woocommerce_catalog_columns' )->input_attrs = array(
		'min'  => 2,
		'max'  => 4,
		'step' => 1,
	);
	$wp_customize->get_control( 'woocommerce_catalog_rows' )->section        = 'magazinex_woocommerce_shop_section';
	$wp_customize->get_control( 'woocommerce_catalog_rows' )->priority       = 130;
	$wp_customize->get_control( 'woocommerce_catalog_rows' )->label          = esc_html__( 'Rows Per Page', 'magazinex' );
}
